Config

Struct Config 

pub struct Config {
Show 73 fields pub config_file: Option<String>, pub genesis_file: Option<String>, pub network_id: u32, pub db_type: String, pub db_dir: String, pub chain_data_dir: String, pub log_dir: String, pub log_level: Option<String>, pub log_format: Option<String>, pub log_display_level: Option<String>, pub http_port: u32, pub http_host: Option<String>, pub http_tls_enabled: Option<bool>, pub http_tls_key_file: Option<String>, pub http_tls_cert_file: Option<String>, pub public_ip: Option<String>, pub sybil_protection_enabled: Option<bool>, pub staking_port: u32, pub staking_tls_key_file: Option<String>, pub staking_tls_cert_file: Option<String>, pub staking_signer_key_file: Option<String>, pub bootstrap_ips: Option<String>, pub bootstrap_ids: Option<String>, pub snow_sample_size: Option<u32>, pub snow_quorum_size: Option<u32>, pub snow_concurrent_repolls: Option<u32>, pub snow_max_time_processing: Option<String>, pub snow_rogue_commit_threshold: Option<u32>, pub snow_virtuous_commit_threshold: Option<u32>, pub network_peer_list_gossip_frequency: Option<String>, pub network_max_reconnect_delay: Option<String>, pub index_enabled: Option<bool>, pub index_allow_incomplete: Option<bool>, pub api_admin_enabled: Option<bool>, pub api_info_enabled: Option<bool>, pub api_keystore_enabled: Option<bool>, pub api_metrics_enabled: Option<bool>, pub api_health_enabled: Option<bool>, pub api_ipcs_enabled: Option<bool>, pub track_subnets: Option<String>, pub plugin_dir: String, pub subnet_config_dir: String, pub chain_config_dir: String, pub state_sync_ids: Option<String>, pub state_sync_ips: Option<String>, pub profile_dir: Option<String>, pub profile_continuous_enabled: Option<bool>, pub profile_continuous_freq: Option<String>, pub profile_continuous_max_files: Option<u32>, pub proposervm_use_current_height: Option<bool>, pub throttler_inbound_node_max_processing_msgs: Option<u64>, pub throttler_inbound_bandwidth_refill_rate: Option<u64>, pub throttler_inbound_bandwidth_max_burst_size: Option<u64>, pub throttler_inbound_cpu_validator_alloc: Option<u64>, pub throttler_inbound_disk_validator_alloc: Option<u64>, pub throttler_inbound_at_large_alloc_size: Option<u64>, pub throttler_inbound_validator_alloc_size: Option<u64>, pub throttler_inbound_node_max_at_large_bytes: Option<u64>, pub snow_mixed_query_num_push_vdr: Option<u64>, pub consensus_accepted_frontier_gossip_frequency: Option<i64>, pub consensus_app_concurrency: Option<i64>, pub consensus_on_accept_gossip_validator_size: Option<u64>, pub consensus_on_accept_gossip_non_validator_size: Option<u64>, pub consensus_on_accept_gossip_peer_size: Option<u64>, pub consensus_accepted_frontier_gossip_peer_size: Option<u64>, pub throttler_outbound_at_large_alloc_size: Option<u64>, pub throttler_outbound_validator_alloc_size: Option<u64>, pub throttler_outbound_node_max_at_large_bytes: Option<u64>, pub network_minimum_timeout: Option<String>, pub network_require_validator_to_connect: Option<bool>, pub network_compression_type: Option<String>, pub tracing_enabled: Option<bool>, pub process_context_file: Option<String>,
}
Available on crate feature avalanchego only.
Represents AvalancheGo configuration. All file paths must be valid on the remote machines. For example, you may configure cert paths on your local laptop but the actual Avalanche nodes run on the remote machines so the paths will be invalid. ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/config ref. https://github.com/ava-labs/avalanchego/blob/v1.9.8/config/flags.go ref. https://github.com/ava-labs/avalanchego/blob/v1.9.8/config/keys.go ref. https://serde.rs/container-attrs.html

Fields

config_file: Option<String>

File path to persist all fields below.

genesis_file: Option<String>

Genesis file path. MUST BE NON-EMPTY for custom network.

network_id: u32

Network ID. Default to custom network ID. Set it to 1 for mainnet. e.g., “mainnet” is 1, “fuji” is 5, “local” is 12345. “utils/constants/NetworkID” only accepts string for known networks. ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/utils/constants#pkg-constants ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/utils/constants#NetworkName

db_type: Stringdb_dir: String

Database directory, must be a valid path in remote host machine.

chain_data_dir: String

Chain data directory, must be a valid path in remote host machine.

log_dir: String

Logging directory, must be a valid path in remote host machine.

log_level: Option<String>

“avalanchego” logging level. See “utils/logging/level.go”. e.g., “INFO”, “FATAL”, “DEBUG”, “VERBO”, etc..

log_format: Option<String>

“avalanchego” logging format. e.g., “json”, etc..

log_display_level: Option<String>http_port: u32

HTTP port.

http_host: Option<String>

HTTP host, which avalanchego defaults to 127.0.0.1. Set it to 0.0.0.0 to expose the HTTP API to all incoming traffic.

http_tls_enabled: Option<bool>http_tls_key_file: Option<String>

MUST BE a valid path in remote host machine.

http_tls_cert_file: Option<String>

MUST BE a valid path in remote host machine.

public_ip: Option<String>

Public IP of this node for P2P communication. If empty, try to discover with NAT.

sybil_protection_enabled: Option<bool>staking_port: u32

Staking port.

staking_tls_key_file: Option<String>

MUST BE a valid path in remote host machine.

staking_tls_cert_file: Option<String>

MUST BE a valid path in remote host machine.

staking_signer_key_file: Option<String>

MUST BE a valid path in remote host machine. Path to the BLS key.

bootstrap_ips: Option<String>bootstrap_ids: Option<String>snow_sample_size: Option<u32>

The sample size k, snowball.Parameters.K. If zero, use the default value set via avalanche node code.

snow_quorum_size: Option<u32>

The quorum size α, snowball.Parameters.Alpha. If zero, use the default value set via avalanche node code.

snow_concurrent_repolls: Option<u32>snow_max_time_processing: Option<String>snow_rogue_commit_threshold: Option<u32>snow_virtuous_commit_threshold: Option<u32>network_peer_list_gossip_frequency: Option<String>network_max_reconnect_delay: Option<String>index_enabled: Option<bool>index_allow_incomplete: Option<bool>api_admin_enabled: Option<bool>api_info_enabled: Option<bool>api_keystore_enabled: Option<bool>api_metrics_enabled: Option<bool>api_health_enabled: Option<bool>api_ipcs_enabled: Option<bool>track_subnets: Option<String>

A list of whitelisted/tracked subnet IDs (comma-separated). From avalanchego v1.9.7, it’s renamed to “track-subnets”. ref. https://github.com/ava-labs/avalanchego/blob/v1.9.8/config/keys.go

plugin_dir: String

Plugin directory. Default to “/data/avalanche-plugins”.

subnet_config_dir: String

Subnet configuration directory (e.g., /data/avalanche-configs/subnets/C.json). If a subnet id is 2ebCneCbwthjQ1rYT41nhd7M76Hc6YmosMAQrTFhBq8qeqh6tt, the config file for this subnet is located at {subnet-config-dir}/2ebCneCbwthjQ1rYT41nhd7M76Hc6YmosMAQrTFhBq8qeqh6tt.json.

chain_config_dir: String

Chain configuration directory (e.g., /data/avalanche-configs/chains/C/config.json). If a Subnet’s chain id is 2ebCneCbwthjQ1rYT41nhd7M76Hc6YmosMAQrTFhBq8qeqh6tt, the config file for this chain is located at {chain-config-dir}/2ebCneCbwthjQ1rYT41nhd7M76Hc6YmosMAQrTFhBq8qeqh6tt/config.json.

state_sync_ids: Option<String>

A comma separated string of explicit nodeID and IPs to contact for starting state sync. Useful for testing. NOTE: Actual state data will be downloaded from nodes specified in the C-Chain config, or the entire network if no list specified there.

state_sync_ips: Option<String>profile_dir: Option<String>

Continuous profile flags

profile_continuous_enabled: Option<bool>profile_continuous_freq: Option<String>profile_continuous_max_files: Option<u32>proposervm_use_current_height: Option<bool>throttler_inbound_node_max_processing_msgs: Option<u64>throttler_inbound_bandwidth_refill_rate: Option<u64>throttler_inbound_bandwidth_max_burst_size: Option<u64>throttler_inbound_cpu_validator_alloc: Option<u64>throttler_inbound_disk_validator_alloc: Option<u64>throttler_inbound_at_large_alloc_size: Option<u64>throttler_inbound_validator_alloc_size: Option<u64>throttler_inbound_node_max_at_large_bytes: Option<u64>snow_mixed_query_num_push_vdr: Option<u64>consensus_accepted_frontier_gossip_frequency: Option<i64>consensus_app_concurrency: Option<i64>consensus_on_accept_gossip_validator_size: Option<u64>consensus_on_accept_gossip_non_validator_size: Option<u64>consensus_on_accept_gossip_peer_size: Option<u64>consensus_accepted_frontier_gossip_peer_size: Option<u64>throttler_outbound_at_large_alloc_size: Option<u64>throttler_outbound_validator_alloc_size: Option<u64>throttler_outbound_node_max_at_large_bytes: Option<u64>network_minimum_timeout: Option<String>network_require_validator_to_connect: Option<bool>network_compression_type: Option<String>tracing_enabled: Option<bool>process_context_file: Option<String>

Implementations

Source

impl Config

pub fn default_main() -> Self

The defaults do not match with the ones in avalanchego, as this is for avalanche-ops based deployments.

pub fn default_fuji() -> Self

The defaults do not match with the ones in avalanchego, as this is for avalanche-ops based deployments.

pub fn default_custom() -> Self

The defaults do not match with the ones in avalanchego, as this is for avalanche-ops based deployments.

pub fn is_mainnet(&self) -> bool

Returns true if the configuration is mainnet.

pub fn is_custom_network(&self) -> bool

Returns true if the configuration is a custom network thus requires a custom genesis file.

pub fn add_track_subnets(&mut self, ids: Option<String>)

pub fn encode_json(&self) -> Result<String>

Converts to string with JSON encoder.

pub fn sync(&self, file_path: Option<String>) -> Result<()>

Saves the current configuration to disk and overwrites the file.

pub fn load(file_path: &str) -> Result<Self>

pub fn validate(&self) -> Result<()>

Validates the configuration.