pub struct Genesis {
    pub network_id: u32,
    pub allocations: Option<Vec<Allocation>>,
    pub start_time: Option<u64>,
    pub initial_stake_duration: Option<u64>,
    pub initial_stake_duration_offset: Option<u64>,
    pub initial_staked_funds: Option<Vec<String>>,
    pub initial_stakers: Option<Vec<Staker>>,
    pub c_chain_genesis: Genesis,
    pub message: Option<String>,
}
Represents Avalanche network genesis configuration. ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/genesis#Config ref. https://serde.rs/container-attrs.html

Fields

network_id: u32allocations: Option<Vec<Allocation>>start_time: Option<u64>

Unix time for start time.

initial_stake_duration: Option<u64>

Number of seconds to stake for the initial stakers.

initial_stake_duration_offset: Option<u64>initial_staked_funds: Option<Vec<String>>

MUST BE come from “initial_stakers”. MUST BE the list of X-chain addresses. Initial staked funds cannot be empty.

initial_stakers: Option<Vec<Staker>>

MUST BE non-empty for an existing network. Non-anchor nodes request “GetAcceptedFrontier” from initial stakers (not from specified anchor nodes).

c_chain_genesis: Genesismessage: Option<String>

Implementations

Creates a new Genesis object with “keys” number of generated pre-funded keys.

Saves the current configuration to disk and overwrites the file.