#[repr(i32)]pub enum EngineType {
Unspecified = 0,
Avalanche = 1,
Snowman = 2,
}Available on crate feature
proto only.Expand description
The consensus engine that should be used when handling a consensus request.
Variants
Implementations
Sourceimpl EngineType
impl EngineType
Sourceimpl EngineType
impl EngineType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.