pub struct PullQuery {
pub chain_id: Bytes,
pub request_id: u32,
pub deadline: u64,
pub container_id: Bytes,
pub engine_type: i32,
pub requested_height: u64,
}Available on crate feature
proto only.Expand description
PullQuery requests the preferences of a remote peer given a container id.
Remote peers should respond to a PullQuery with a Chits message
Fields
chain_id: BytesChain being requested from
request_id: u32Unique identifier for this request
deadline: u64Timeout (ns) for this request
container_id: BytesContainer id being gossiped
engine_type: i32Consensus type to handle this message
requested_height: u64Requesting peer’s last accepted height
Implementations
Sourceimpl PullQuery
impl PullQuery
Sourcepub fn engine_type(&self) -> EngineType
pub fn engine_type(&self) -> EngineType
Returns the enum value of engine_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_engine_type(&mut self, value: EngineType)
pub fn set_engine_type(&mut self, value: EngineType)
Sets engine_type to the provided enum value.