InitializeRequest

Struct InitializeRequest 

pub struct InitializeRequest {
Show 14 fields pub network_id: u32, pub subnet_id: Bytes, pub chain_id: Bytes, pub node_id: Bytes, pub public_key: Bytes, pub x_chain_id: Bytes, pub c_chain_id: Bytes, pub avax_asset_id: Bytes, pub chain_data_dir: String, pub genesis_bytes: Bytes, pub upgrade_bytes: Bytes, pub config_bytes: Bytes, pub db_server_addr: String, pub server_addr: String,
}
Available on crate feature proto only.

Fields

network_id: u32subnet_id: Byteschain_id: Bytesnode_id: Bytespublic_key: Bytes

public_key is the BLS public key that would correspond with any signatures produced by the warp messaging signer

x_chain_id: Bytesc_chain_id: Bytesavax_asset_id: Byteschain_data_dir: Stringgenesis_bytes: Bytesupgrade_bytes: Bytesconfig_bytes: Bytesdb_server_addr: Stringserver_addr: String

server_addr is the address of the gRPC server which serves the messenger, keystore, shared memory, blockchain alias, subnet alias, and appSender services