pub struct Tx {
pub metadata: Option<Metadata>,
pub network_id: u32,
pub blockchain_id: Id,
pub transferable_inputs: Option<Vec<Input>>,
pub transferable_outputs: Option<Vec<Output>>,
pub memo: Option<Vec<u8>>,
}Expand description
Fields
metadata: Option<Metadata>network_id: u32blockchain_id: Idtransferable_inputs: Option<Vec<Input>>transferable_outputs: Option<Vec<Output>>memo: Option<Vec<u8>>Implementations
Sourceimpl Tx
impl Tx
pub fn type_name() -> String
pub fn type_id() -> u32
Sourcepub fn pack(&self, codec_version: u16, type_id: u32) -> Result<Packer>
pub fn pack(&self, codec_version: u16, type_id: u32) -> Result<Packer>
“Tx.Unsigned” is implemented by “avax.BaseTx” but for marshal, it’s passed as an interface. Then marshaled via “avalanchego/codec/linearcodec.linearCodec” which then calls “genericCodec.marshal”. ref. “avalanchego/vms/avm.Tx.SignSECP256K1Fx” ref. “avalanchego/codec.manager.Marshal” ref. “avalanchego/codec.manager.Marshal(codecVersion, &t.UnsignedTx)” ref. “avalanchego/codec/linearcodec.linearCodec.MarshalInto” ref. “avalanchego/codec/reflectcodec.genericCodec.MarshalInto” ref. “avalanchego/codec/reflectcodec.genericCodec.marshal”
Returns the packer itself so that the following marshals can reuse.
“BaseTx” is an interface in Go (reflect.Interface) thus the underlying type must be specified by the caller TODO: can we do better in Rust? Go does so with reflect… e.g., pack prefix with the type ID for “avm.BaseTx” (linearCodec.PackPrefix) ref. “avalanchego/codec/linearcodec.linearCodec.MarshalInto” ref. “avalanchego/codec/reflectcodec.genericCodec.MarshalInto”