Node ID utilities.
Structs
- Id
- ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/ids#ShortID ref. https://docs.rs/zerocopy/latest/zerocopy/trait.AsBytes.html#safety
- Ids
Constants
Functions
- deserialize_
id - Custom deserializer. ref. https://serde.rs/impl-deserialize.html
- deserialize_
ids - Custom deserializer. ref. https://serde.rs/impl-deserialize.html
- must_
deserialize_ id - Custom deserializer. Use #[serde(deserialize_with = “ids::must_deserialize_id”)] to serde without derive. ref. https://serde.rs/impl-deserialize.html
- must_
deserialize_ ids - Custom deserializer. Use #[serde(deserialize_with = “short::must_deserialize_ids”)] to serde with derive. ref. https://serde.rs/impl-deserialize.html
- new_set
- Return a new NodeIdSet with initial capacity [size]. More or less than [size] elements can be added to this set. Using NewNodeIDSet() rather than ids.NodeIDSet{} is just an optimization that can be used if you know how many elements will be put in this set.
Type Aliases
- Set
- Set is a set of NodeIds ref. https://pkg.go.dev/github.com/ava-labs/avalanchego/ids#NewNodeIDSet